@@ -13,7 +13,7 @@ my $usage = <<__EOUSAGE__;
 #
 # Required:
 #
-#  --matrix <string>       TMM.EXPR.matrix
+#  --matrix|m <string>       TMM.EXPR.matrix
 #
 # Optional:
 #
@@ -28,7 +28,7 @@ my $usage = <<__EOUSAGE__;
 #
 # Misc:
 #
-#  --samples <string>                     sample-to-replicate mappings (provided to run_DE_analysis.pl)
+#  --samples|s <string>                     sample-to-replicate mappings (provided to run_DE_analysis.pl)
 #
 #  --max_DE_genes_per_comparison <int>    extract only up to the top number of DE features within each pairwise comparison.
 #                                         This is useful when you have massive numbers of DE features but still want to make
@@ -43,6 +43,7 @@ my $usage = <<__EOUSAGE__;
 #       --GO_annots <string>              GO annotations file
 #       --gene_lengths <string>           lengths of genes file
 #
+#       --include_GOplot                  optional: will generate inputs to GOplot and attempt to make a preliminary pdf plot/report for it.
 #
 ##############################################################
 
@@ -74,12 +75,12 @@ my $order_columns_by_samples_file = 0;
 my $examine_GO_enrichment_flag;
 my $GO_annots_file;
 my $gene_lengths_file;
-
+my $RUN_GOPLOT = 0;
 
 
 &GetOptions (  'h' => \$help_flag,
                
-               'matrix=s' => \$matrix_file,
+               'matrix|m=s' => \$matrix_file,
                'P=f' => \$p_value,
                'C=f' => \$log2_fold_change,
                'output=s' => \$output_prefix,
@@ -93,11 +94,15 @@ my $gene_lengths_file;
                'examine_GO_enrichment' => \$examine_GO_enrichment_flag,
                'GO_annots=s' => \$GO_annots_file,
                'gene_lengths=s' => \$gene_lengths_file,
-                 
-               'samples=s' => \$samples_file,
+               'include_GOplot' => \$RUN_GOPLOT,
+
+  
+               'samples|s=s' => \$samples_file,
              
                "order_columns_by_samples_file" => \$order_columns_by_samples_file,
 
+               
+               
                );
 
 
@@ -205,7 +210,7 @@ main: {
     
     {
         open (my $ofh, ">$diff_expr_matrix") or die "Error, cannot write to file $diff_expr_matrix";
-        print $ofh "\t$matrix_header\n";
+        print $ofh "$matrix_header\n";
         foreach my $acc (keys %diffExpr) {
             my $counts_row = $read_count_rows{$acc} or die "Error, no read counts row for $acc";
             print $ofh join("\t", $acc, $counts_row) . "\n";
@@ -238,7 +243,7 @@ sub cluster_diff_expressed_transcripts {
         $cmd .= " -s $samples_file";
                 
         if ($order_columns_by_samples_file) {
-            $cmd .= " --order_columns_by_samples_file ";
+            $cmd .= " --order_columns_by_samples_file --sample_clust none ";
         }
 
     }
@@ -284,18 +289,18 @@ sub parse_result_files_find_diffExp {
     
     foreach my $result_file (@$result_files_aref) {
         
-        $result_file =~ /matrix\.(\S+)_vs_(\S+)\.[^\.]+\.DE_results$/ or die "Error, cannot extract condition names from $result_file";
-        my ($condA, $condB) = ($1, $2);
+        my ($condA, $condB) = &get_sample_pairs_from_DE_results_file($result_file);
         
         my $pairwise_samples_file = "$result_file.samples";
         { 
             ## write a samples file
             open (my $ofh, ">$pairwise_samples_file") or die "Error, cannot write to $pairwise_samples_file";
             foreach my $cond ($condA, $condB) {
-                if (! exists $samples_to_replicates_href->{$cond}) {
-                    die "\n\n\tError, not finding replicates corresponding to cond: $cond.  Please use the --samples parameter to specify sample/replicate relationships\n\n" . Dumper($samples_to_replicates_href);
+                my @replicates = ($cond);
+                if (exists $samples_to_replicates_href->{$cond}) {
+                   @replicates = @{$samples_to_replicates_href->{$cond}}; 
                 }
-                my @replicates = @{$samples_to_replicates_href->{$cond}};
+                
                 foreach my $replicate (@replicates) {
                     print $ofh join("\t", $cond, $replicate) . "\n";
                 }
@@ -308,26 +313,28 @@ sub parse_result_files_find_diffExp {
         
         my $condA_up_subset_file = "$result_file_out_prefix.$condA-UP.subset";
         my $condB_up_subset_file = "$result_file_out_prefix.$condB-UP.subset";
-
+        my $either_subset_file = "$result_file_out_prefix.DE.subset";
+        
+        
         open (my $condA_up_ofh, ">$condA_up_subset_file") or die "Error, cannot write to $condA_up_subset_file";
-        open (my $condB_up_ofh, ">$result_file_out_prefix.$condB-UP.subset") or die "Error, cannot write to $condB_up_subset_file";
+        open (my $condB_up_ofh, ">$condB_up_subset_file") or die "Error, cannot write to $condB_up_subset_file";
+        open (my $cond_either_up_ofh, ">$either_subset_file") or die "Error, cannot write to $either_subset_file";
         
         my $count = 0;
 
         my $header = <$fh>;
         chomp $header;
-        unless ($header =~ /^id\t/) {
-            print $condA_up_ofh "id\t";
-            print $condB_up_ofh "id\t";
-        }
+        
         print $condA_up_ofh "$header\t$fpkm_matrix_header\n";
         print $condB_up_ofh "$header\t$fpkm_matrix_header\n";
-
+        print $cond_either_up_ofh "$header\t$fpkm_matrix_header\n";
+        
         my $countA = 0;
         my $countB = 0;
 
         my %condA_up_genes;
         my %condB_up_genes;
+        my %either_up_genes;
         
         my $rank = 0;
         while (<$fh>) {
@@ -354,8 +361,14 @@ sub parse_result_files_find_diffExp {
                     $diff_expr{$id} = 1;
                     
                     my $matrix_counts = $read_fpkm_rows_href->{$id} || die "Error, no counts from matrix for $id";
-            
-                    if ($log_fold_change > 0) {
+
+                    ######################################
+                    # log fold changes should be log2(A/B)
+
+                    $either_up_genes{$id} = $rank;
+                    print $cond_either_up_ofh "$line\t$matrix_counts\n";
+                    
+                    if ($log_fold_change < 0) {
                         
                         print $condB_up_ofh "$line\t$matrix_counts\n";
                         $countB++;
@@ -381,17 +394,75 @@ sub parse_result_files_find_diffExp {
             
             # conditionB enriched heatmaps
             &write_matrix_generate_heatmap("$condB_up_subset_file.matrix", \%condB_up_genes, $read_fpkm_rows_href, $fpkm_matrix_header, $pairwise_samples_file);
+
+            # either enriched heatmaps
+            &write_matrix_generate_heatmap("$either_subset_file.matrix", \%either_up_genes, $read_fpkm_rows_href, $fpkm_matrix_header, $pairwise_samples_file);
             
         }
         
         ## do GO enrichment analysis
         if ($examine_GO_enrichment_flag) {
             
-            my $cmd = "$FindBin::RealBin/run_GOseq.pl --GO_assignments $GO_annots_file --lengths $gene_lengths_file --genes_single_factor $condA_up_subset_file";
-            &process_cmd($cmd) if $countA;
+            my $background_file = $result_file;
+            $background_file =~ s/\.DE_results$/\.count_matrix/ or die "Error, cannot modify $result_file to count_matrix name";
 
-            $cmd = "$FindBin::RealBin/run_GOseq.pl --GO_assignments $GO_annots_file --lengths $gene_lengths_file --genes_single_factor $condB_up_subset_file";
-            &process_cmd($cmd) if $countB;
+            my $cmd = "$FindBin::RealBin/run_GOseq.pl --GO_assignments $GO_annots_file "
+                . " --lengths $gene_lengths_file --genes_single_factor $condA_up_subset_file"
+                . " --background $background_file ";
+
+            eval {
+                &process_cmd($cmd) if $countA;
+            };
+            if ($@) {
+                print STDERR "WARNING, go-seq failed for $condA_up_subset_file: $@";
+                system("touch $condA_up_subset_file.FAILED");
+            }
+            
+                
+            $cmd = "$FindBin::RealBin/run_GOseq.pl --GO_assignments $GO_annots_file "
+                . " --lengths $gene_lengths_file --genes_single_factor $condB_up_subset_file"
+                . " --background $background_file ";
+            
+
+            eval {
+                &process_cmd($cmd) if $countB;
+            };
+            if ($@) {
+                print STDERR "WARNING, go-seq failed for $condB_up_subset_file: $@";
+                system("touch $condB_up_subset_file.FAILED");
+            }
+
+            if ($countA + $countB) {
+                
+                $cmd = "$FindBin::RealBin/run_GOseq.pl --GO_assignments $GO_annots_file "
+                    . " --lengths $gene_lengths_file --genes_single_factor $either_subset_file"
+                    . " --background $background_file ";
+            
+                eval {
+                    &process_cmd($cmd);
+                };
+                if ($@) {
+                    print STDERR "Warning, go-seq failed for $either_subset_file: $@";
+                    system("touch $either_subset_file.FAILED");
+                }
+                
+                if ($RUN_GOPLOT) {
+                    $cmd = "$FindBin::RealBin/prep_n_run_GOplot.pl --GO_annots $GO_annots_file "
+                        . " --DE_subset $either_subset_file "
+                        . " --DE_GO_enriched $either_subset_file.GOseq.enriched "
+                        . " --tmpdir $either_subset_file.GOseq.enriched.GOplot_dat"
+                        . " --pdf_filename $either_subset_file.GOseq.enriched.GOplot_dat.pdf";
+
+                    eval {
+                        &process_cmd($cmd);
+                    };
+                    if ($@) {
+                        # can't afford for this to be fatal, so just reporting a failure message for this part.
+                        print STDERR "WARNING: GOplot failed to run successfully on $either_subset_file.GOseq.enriched\n";
+                    }
+                }
+            }
+            
             
         }
         
@@ -402,7 +473,7 @@ sub parse_result_files_find_diffExp {
     
     {
         # write DE count matrix:
-        my $num_DE_counts_outfile = "numDE_feature_counts.P${max_p_value}_C${min_abs_log2_fold_change}.matrix";
+        my $num_DE_counts_outfile = "DE_feature_counts.P${max_p_value}_C${min_abs_log2_fold_change}.matrix";
         open (my $ofh, ">$num_DE_counts_outfile") or die "Error, cannot write to file $num_DE_counts_outfile";
         my @conditions = sort keys %DE_pair_counts;
         print $ofh "\t" . join("\t", @conditions) . "\n";
@@ -458,7 +529,7 @@ sub write_matrix_generate_heatmap {
     
     foreach my $gene (sort {$genes_href->{$a}<=>$genes_href->{$b}} keys %$genes_href) { # output in rank of DE
         
-        my $row = $fpkm_matrix_rows_href->{$gene} or die "Error, no fpkm row for gene $gene";
+        my $row = $fpkm_matrix_rows_href->{$gene} or die "Error, no expression values row for gene $gene";
         print $ofh "$gene\t$row\n";
     }
     close $ofh;
@@ -480,3 +551,26 @@ sub write_matrix_generate_heatmap {
  
     return;
 }
+
+
+####
+sub get_sample_pairs_from_DE_results_file {
+    my ($result_file) = @_;
+
+    my ($header, $line) = split(/\n/, `head -n2 $result_file`);
+
+    unless ($header =~ /^sampleA\tsampleB/) {
+        die "Error, header [$header] of $result_file lacks expected formatting starting with sampleA\tsampleB";
+    }
+    my @header_comps = split(/\t/, $header);
+    
+    my @x = split(/\t/, $line);
+    unless (scalar(@x) == scalar(@header_comps) + 1) {
+        die "Error, top lines of result file: $result_file do not meet expectations for the R data.frame ";
+    }
+    my $sampleA = $x[1];
+    my $sampleB = $x[2];
+
+    return($sampleA, $sampleB);
+}
+
