@@ -67,7 +67,7 @@ main: {
 
     print $ofh "# capture list of genes for functional enrichment testing\n";
     if ($genes_single_factor_file) {
-        print $ofh "factor_labeling = read.table(\"$genes_single_factor_file\", row.names=1)\n";
+        print $ofh "factor_labeling = read.table(\"$genes_single_factor_file\", header=T, row.names=1)\n";
         print $ofh "factor_labeling[,1] = rep('custom_list', dim(factor_labeling)[1])\n";
         print $ofh "factor_labeling = factor_labeling[,1,drop=F]\n";
     }
@@ -184,6 +184,13 @@ main: {
     
     print $ofh "    descr = unlist(lapply(result_table\$category, get_GO_term_descr))\n";
     print $ofh "    result_table\$go_term = descr;\n";
+   
+    print $ofh "    result_table\$gene_ids = do.call(rbind, lapply(result_table\$category, function(x) { \n" .
+               "            gene_list = GO_to_gene_list[[x]]\n" .
+               "            gene_list = gene_list[gene_list %in% gene_ids_in_feature_cat]\n" .
+               "            paste(gene_list, collapse=', ');\n" .
+               "     }) )\n";
+
     print $ofh "    write.table(result_table[order(result_table\$under_represented_pvalue),], file=go_depleted_filename, sep='\t', quote=F, row.names=F)\n";
     
             
