@@ -150,8 +150,10 @@ class Node_alignment:
 
         node_list = list(self.get_node_set_at_column_pos(col_pos))
 
-        return node_list[ 0 ]
-    
+        if node_list:
+            return node_list[ 0 ]
+        else:
+            return None
 
     def get_node_LIST_at_column_pos(self, col_pos):
 
@@ -269,15 +271,15 @@ class Node_alignment:
 
         # walk the node list and merge unbranched stretches into single nodes
         block_breakpoints = []
-        prev_col_node_set = self.get_node_occupancy_at_column_pos(0)
+        prev_col_node_occupancy = self.get_node_occupancy_at_column_pos(0)
         for i in range(1,width):
-            node_column_set = self.get_node_occupancy_at_column_pos(i)
+            node_column_occupancy = self.get_node_occupancy_at_column_pos(i)
 
             #print("Comparing {} to {} == {}".format(prev_col_node_set, node_column_set, prev_col_node_set == node_column_set))
 
-            if node_column_set != prev_col_node_set:
+            if node_column_occupancy != prev_col_node_occupancy:
                 block_breakpoints.append(i)
-            prev_col_node_set = node_column_set
+            prev_col_node_occupancy = node_column_occupancy
 
         block_breakpoints.append(width)
 
@@ -290,22 +292,27 @@ class Node_alignment:
                 node_to_add = None
                 if len(blocked_nodes) > 1:
                     node_to_add = TNode.TNode.merge_nodes(blocked_nodes)
-                else:
+                elif len(blocked_nodes) == 1:
                     node_to_add = blocked_nodes[ 0 ]
 
-                blocked_node_occupancy = self.get_node_occupancy_at_column_pos(i-1)
-                squeezed_alignment.append_node_according_to_occupancy_pattern(node_to_add, blocked_node_occupancy)
+                if node_to_add is not None:
+                    blocked_node_occupancy = self.get_node_occupancy_at_column_pos(i-1)
+                    squeezed_alignment.append_node_according_to_occupancy_pattern(node_to_add, blocked_node_occupancy)
 
                 blocked_nodes = list() # reinit
             
             # add to running block
             if i < width:
-                blocked_nodes.append(self.get_representative_column_node(i))
-        
+                representative_node = self.get_representative_column_node(i)
+                if representative_node is not None:
+                    blocked_nodes.append(representative_node)
+
+        #print("squeezed alignment: {}".format(squeezed_alignment))
+              
         return squeezed_alignment
 
 
-    def to_gene_fasta_and_gtf(self, gene_name):
+    def to_gene_fasta_and_gtf(self, gene_name, long_read_mappings = None):
 
         transcript_names = self.get_transcript_names()
         
@@ -375,8 +382,14 @@ class Node_alignment:
             path_list = transcript_to_Trinity_fa_path[transcript_name]
             #logger.debug("path list: " + str(path_list))
             path_list_text = " ".join(path_list)
-            trinity_fasta_text += ">{} len={} path=[{}]\n{}\n".format(transcript_name, len(transcript_seq),
-                                                                      path_list_text, transcript_seq)
+            long_read_mappings_txt = ""
+            if long_read_mappings is not None and transcript_name in long_read_mappings:
+                long_read_mappings_txt = " " + long_read_mappings[transcript_name]
+
+            
+            trinity_fasta_text += ">{} len={} path=[{}]{}\n{}\n".format(transcript_name, len(transcript_seq),
+                                                                        path_list_text, long_read_mappings_txt,
+                                                                        transcript_seq)
         
         return (gene_seq, gene_gtf, trinity_fasta_text, transcript_to_malign)
         
@@ -404,8 +417,12 @@ class Node_alignment:
 
             logger.debug("repr node: {}".format(repr_node.toString()))
         
-            transcripts = repr_node.get_transcripts()
-
+            occupancy_at_node_pos = self.get_node_occupancy_at_column_pos(i)
+            transcripts = set()
+            for j, transcript_name in enumerate(self.get_transcript_names()):
+                if occupancy_at_node_pos[j] is True:
+                    transcripts.add(transcript_name)
+            
             loc_id = repr_node.get_loc_id()
             if reset_node_ids:
                 loc_id = "loc_" + str(i)
@@ -494,6 +511,10 @@ class Node_alignment:
             self.transcript_names = revised_transcript_names
             self.aligned_nodes = revised_aligned_nodes
 
+            #print("-revised transcript names: {}".format(self.transcript_names))  ## DEBUGGING
+            #print("-revised aligned nodes: {}".format(self.aligned_nodes)) ## DEBUGGING
+
+            
             self.remove_empty_aligned_node_columns()
             
             return True
@@ -506,8 +527,8 @@ class Node_alignment:
     def remove_empty_aligned_node_columns(self):
 
         column_indices_to_remove = list()
-
-        for col_pos in range(0, len(self)):
+        
+        for col_pos in range(0, self.width()):
             node_list = list(self.get_node_set_at_column_pos(col_pos))
             if len(node_list) == 0:
                 column_indices_to_remove.append(col_pos)
