@@ -14,7 +14,8 @@ ${TRINITY_HOME}/Trinity --seqType fq --max_memory 2G \
               --left reads.left.fq.gz \
               --right reads.right.fq.gz \
               --SS_lib_type RF \
-              --CPU 1 
+              --CPU 1 \
+              --no_cleanup
 
 ##### Done Running Trinity #####
 
