@@ -20,3 +20,13 @@ fi
 
 
 $TRINITY_HOME/Trinity --genome_guided_max_intron 1000 --genome_guided_bam SP2.chr.bam --max_memory 2G  --output test_GG_use_bam_trinity_outdir
+
+asmsize=$(wc -c <"test_GG_use_bam_trinity_outdir/Trinity-GG.fasta")
+if [ $asmsize -le 50000 ]; then
+    echo "Error, test_GG_use_bam_trinity_outdir/Trinity-GG.fasta potentially incomplete"
+    exit 1
+else
+    echo "ok"
+    exit 0
+fi
+
