@@ -167,19 +167,19 @@ my $usage = <<__EOUSAGE__;
 #
 #   ## Just prepare the reference for alignment and abundance estimation
 #
-#    $0 --transcripts Trinity.fasta --est_method RSEM --aln_method bowtie --trinity_mode --prep_reference
+#    $0 --transcripts Trinity.fasta --est_method salmon --trinity_mode --prep_reference
 #
 #   ## Run the alignment and abundance estimation (assumes reference has already been prepped, errors-out if prepped reference not located.)
 #
-#    $0 --transcripts Trinity.fasta --seqType fq --left reads_1.fq --right reads_2.fq --est_method RSEM --aln_method bowtie --trinity_mode --output_dir rsem_outdir
+#    $0 --transcripts Trinity.fasta --seqType fq --left reads_1.fq --right reads_2.fq --est_method salmon --trinity_mode --output_dir salmon_quant
 #
 ##  ## prep the reference and run the alignment/estimation
 #
-#    $0 --transcripts Trinity.fasta --seqType fq --left reads_1.fq --right reads_2.fq --est_method RSEM --aln_method bowtie --trinity_mode --prep_reference --output_dir rsem_outdir
+#    $0 --transcripts Trinity.fasta --seqType fq --left reads_1.fq --right reads_2.fq --est_method salmon --trinity_mode --prep_reference --output_dir salmon_quant
 #
 #   ## Use a samples.txt file:
 #
-#    $0 --transcripts Trinity.fasta --est_method RSEM --aln_method bowtie2 --prep_reference --trinity_mode --samples_file samples.txt --seqType fq  
+#    $0 --transcripts Trinity.fasta --est_method salmon --prep_reference --trinity_mode --samples_file samples.txt --seqType fq  
 #
 #########################################################################
 
@@ -326,11 +326,12 @@ unless ($est_method =~ /^(RSEM|kallisto|salmon|none)$/i) {
 my @samples_to_process;
 if ($samples_file) {
     @samples_to_process = &parse_samples_file($samples_file);
-    if ($samples_idx >= 0) {
+    if ($samples_idx > 0) {
         my $num_samples = scalar(@samples_to_process);
         if ($samples_idx > $num_samples) {
             die "Error, sample index $samples_idx > $num_samples num samples ";
         }
+        @samples_to_process = ($samples_to_process[$samples_idx-1]); # run only that sample
     }
 }
 elsif ( ($left && $right) || $single) {
@@ -343,7 +344,6 @@ elsif ( ($left && $right) || $single) {
 }
 
 
-
 my $PE_mode = 1;
 
 if ($single || (@samples_to_process && $samples_to_process[0]->{single})) {
@@ -401,7 +401,7 @@ if ( $thread_count !~ /^\d+$/ ) {
     
         
     foreach my $tool (@tools) {
-        my $p = `which $tool`;
+        my $p = `sh -c "command -v $tool"`;
         unless ($p =~ /\w/) {
             warn("ERROR, cannot find $tool in PATH setting: $ENV{PATH}\n\n");
             $missing = 1;
