@@ -50,7 +50,8 @@ sub generate_ascii_illustration {
         #$ascii_illustration->add_feature($ref_acc, 1, $length, "=");
         
         my @matches = grep { $_->{ref_acc} eq $ref_acc } @hits;
-        @matches = reverse sort {$a->{bitscore}<=>$b->{bitscore}} @matches;
+        #@matches = reverse sort {$a->{bitscore}<=>$b->{bitscore}} @matches;
+        @matches = sort {$a->{ref_start}<=>$b->{ref_start}} @matches;
 
 
         foreach my $match (@matches) {
@@ -71,6 +72,10 @@ sub generate_ascii_illustration {
             if ($pct_of_target_aligned < $MIN_PCT_ALIGNED) { next; }
 
             my $target_feature_name = "$target_acc $target_start-$target_end:$target_length ($pct_of_target_aligned\% aln, $per_id\% ID)";
+
+            if ($target_start > $target_end) {
+                ($ref_start, $ref_end) = ($ref_end, $ref_start);
+            }
             
             $ascii_illustration->add_feature($target_feature_name, $ref_start, $ref_end, "-");
             
