@@ -27,6 +27,11 @@ my $usage = <<__EOUSAGE__;
 #  -I|--max_intron_length <int>   maximum intron length (default: 100000)
 #
 #  --incl_out_gff3             include gff3 formatted output file for alignments.
+#  --allow_secondary           allow secondary alignments (default secondary=no)
+#
+#  --eqx                       include --eqx flag
+#  --cs                        include long format via --cs w/ minimap2
+#  --hq                        pacbio CCS reads (--splice:hq for mm2)
 #
 #######################################################################
 
@@ -44,7 +49,10 @@ my $help_flag;
 my $output;
 my $max_intron_length = 100000;
 my $incl_out_gff3;
-
+my $allow_secondary = 0;
+my $include_cs_flag = 0;
+my $include_eqx_flag = 0;
+my $include_hq_flag = 0;
 
 &GetOptions( 'h' => \$help_flag,
              'genome=s' => \$genome,
@@ -54,6 +62,9 @@ my $incl_out_gff3;
              'o|output=s' => \$output,
              'I|max_intron_length=i' => \$max_intron_length,
              'incl_out_gff3' => \$incl_out_gff3,
+             'allow_secondary' => \$allow_secondary,
+             'cs' => \$include_cs_flag,
+             'hq' => \$include_hq_flag,
     );
 
 
@@ -66,53 +77,71 @@ unless ($genome && $transcripts) {
     die $usage;
 }
 
-unless ($output) {
-    $output = basename($transcripts) . ".mm2.bam";
+
+my $include_cs_param = "";
+my $include_cs_token = "";
+if ($include_cs_flag) {
+    $include_cs_param = "--cs";
+    $include_cs_token = ".cs";
 }
 
+my $include_eqx_param = "";
+my $include_eqx_token = "";
+if ($include_eqx_flag) {
+    $include_eqx_param = "--eqx";
+    $include_eqx_token = ".eqx";
+}
+
+
+my $include_hq_param = "";
+my $include_hq_token = "";
+if ($include_hq_flag) {
+    $include_hq_param = ":hq";
+    $include_hq_token = ".hq";
+}
+
+
+unless ($output) {
+    $output = basename($transcripts) . ".mm2${include_cs_token}${include_eqx_token}${include_hq_token}.bam";
+}
+
+
+
+
 main: {
 
 	
-	my $genomeBaseDir = dirname($genome);
-	my $genomeName = basename($genome);
-	my $genomeDir = "$genomeBaseDir/$genomeName" . ".mm2";
+    my $genomeBaseDir = dirname($genome);
+    my $genomeName = basename($genome);
+    my $mm2_idx = "$genomeBaseDir/$genomeName" . ".mm2";
     
+    my $cwd = cwd();
 
-    unless (-d $genomeDir) {
-        &process_cmd("mkdir $genomeDir");
-    }
-    
-	my $cwd = cwd();
-	
-    my $mm2_idx = "$genomeDir/$genomeName.mmi";
-	
-    my $splice_file = "";
-    if ($gtf) {
-        $splice_file = "$genomeDir/anno.bed";
-    }
-
+    my $splice_file = "$mm2_idx.splice.bed";
 
     unless (-e $mm2_idx) {
         
         my $cmd = "minimap2 -d $mm2_idx $genome";
         &process_cmd($cmd);
-
-        if ($gtf) {
-            my $cmd = "paftools.js gff2bed $gtf > $splice_file";
-            &process_cmd($cmd);
-        }
-	
     }
+
     
+    if ($gtf && ! -s $splice_file) {
+	my $cmd = "paftools.js gff2bed $gtf > $splice_file";
+	&process_cmd($cmd);
+    }
 	
-	## run minimap2
+	
+    ## run minimap2
 
     my $splice_param = "";
     if ($splice_file) {
         $splice_param = "--junc-bed $splice_file";
     }
 
-    my $cmd = "minimap2 -ax splice $splice_param --secondary=no -O6,24 -B4 -L -t $CPU -cs -ub -G $max_intron_length $mm2_idx $transcripts > $output.tmp.sam";
+    my $secondary = ($allow_secondary) ? "" : "--secondary=no";
+
+    my $cmd = "minimap2 --sam-hit-only  -ax splice$include_hq_param $splice_param $secondary -t $CPU -u b -G $max_intron_length $include_cs_param $include_eqx_param $mm2_idx $transcripts > $output.tmp.sam";
     &process_cmd($cmd);
 
     $cmd = "samtools view -Sb -T $genome $output.tmp.sam -o $output.tmp.unsorted.bam";
@@ -130,8 +159,6 @@ main: {
         &process_cmd($cmd);
     }
 
-
-
     unlink("$output.tmp.sam", "$output.tmp.unsorted.bam");
     
 	exit(0);
